@@ -16,7 +16,7 @@
  * along with ColorCode. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QtGui>
+#include <QtWidgets>
 
 #include "settings.h"
 #include "ccsolver.h"
@@ -41,7 +41,7 @@ using namespace std;
 
 ColorCode* ColorCode::INSTANCE = NULL;
 
-const QString ColorCode::VERSION = "0.7.2";
+const QString ColorCode::VERSION = "0.8.5";
 
 volatile bool ColorCode::mNoAct       = false;
 volatile bool ColorCode::mIgnoreGuess = false;
@@ -113,7 +113,7 @@ ColorCode::ColorCode()
 
     QTime midnight(0, 0, 0);
     qsrand(midnight.secsTo(QTime::currentTime()));
-    
+
     Init();
 }
 
@@ -213,7 +213,7 @@ void ColorCode::Init()
     mTimerBtn->SetWidth(261);
     mTimerBtn->SetLabel("");
     mScene->addItem(mTimerBtn);
-    mTimerBtn->scale(0.44, 0.44);
+    mTimerBtn->setScale(0.44);
     mTimerBtn->setPos(102, 110);
     mTimerBtn->setZValue(LAYER_HINTS);
     mTimerBtn->InvertStates();
@@ -225,7 +225,7 @@ void ColorCode::Init()
     mSolutionRowBg->SetWidth(219);
     mSolutionRowBg->SetLabel("");
     mScene->addItem(mSolutionRowBg);
-    mSolutionRowBg->scale(1.14, 1.14);
+    mSolutionRowBg->setScale(1.14);
     mSolutionRowBg->setPos(35, 66);
     mSolutionRowBg->setZValue(LAYER_ROWS);
     mSolutionRowBg->SetStatesOpacity(1.0, 0.1);
@@ -237,6 +237,7 @@ void ColorCode::Init()
 
     mSolver = new CCSolver(this);
     connect(mSolver, SIGNAL(finished()), this, SLOT(SetSolverGuessSlot()));
+    connect(mSolver, SIGNAL(GuessDoneSignal()), this, SLOT(SetSolverGuessSlot()));
     mHintsDelayTimer = new QTimer();
     mHintsDelayTimer->setSingleShot(true);
     mHintsDelayTimer->setInterval(500);
@@ -1422,7 +1423,7 @@ void ColorCode::SetLevelSlot()
     {
         mGameInput = NULL;
         NewGame();
-    }    
+    }
 }
 
 void ColorCode::SetGameModeSlot()
@@ -1535,7 +1536,7 @@ void ColorCode::RowSolutionSlot(int ix)
             {
                 bool valid = true;
                 if (!mActDoubles->isChecked())
-                {                    
+                {
                     int i;
                     int check[mColorCnt];
                     for (i = 0; i < mColorCnt; ++i)
@@ -1923,7 +1924,7 @@ void ColorCode::ResetGame()
     ++mGameCnt;
 
     mPegFactory->ApplyColorCnt();
-    
+
     CheckDoublesSetting();
 
     mDoubles = GetDoublesInput();
