@@ -20,7 +20,7 @@
 #define TIMEDISPLAYBG_H
 
 #include <QGraphicsItem>
-#include <QtGui>
+#include <QtWidgets>
 
 class TimeDisplayBg : public QGraphicsItem
 {
